[−][src]Struct texel_types::Position2D
2D position
Fields
x: i32y: i32Implementations
impl Position2D[src]
pub fn from_xy(x: i32, y: i32) -> Self[src]
pub fn apply(&mut self, translation: Translation, bounds: Bounds) -> bool[src]
Applies given Translation to this Position2D with regards to the provided
Bounds area. If Bounds is binding ensures position does not reach outside.
pub fn area(self, other: Position2D) -> Bounds[src]
Create bounds from two points
pub fn area_texels(self, dim: Dimension) -> Vec<Position2D>[src]
Create the list of all positions in given area from point with given dimension